#!/usr/bin/env python
#  PromptNuFlux plotter.py
#  Author: Luca Rottoli
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.patches as mpatches

import argparse
from argparse import RawTextHelpFormatter

def main():

	#parsing arguments
	parser = argparse.ArgumentParser(description=" FLUX: Replace FLUX [FLUX ...] with the desired flux model(s): BPL, H3P, H3A, H14A, H14B\n -b: Add total uncertainty band to the plot. Default: no band\n OUT: replace it with a name for the output plot. Default: prompt_fluxes.pdf\n\n Example: python plotter.py -f BPL H3P -b -o prompt_fluxes.pdf", formatter_class=RawTextHelpFormatter)
	parser.add_argument("-f", "--flux", type=str, required=True, nargs='+')
	parser.add_argument('-b', '--band', action='store_true')
	parser.add_argument('-o', '--out', type=str, default="prompt_fluxes.pdf")
	args = parser.parse_args()

	band   = args.band
	fluxes = args.flux
	output = args.out
	
	nfluxes = len(fluxes)

	fig = plt.figure()
	fig = plt.figure(figsize=(9, 6))
	ax1 = fig.add_subplot(111)

	#labels style
	#font.serif         : Times, Palatino, New Century Schoolbook, Bookman, Computer Modern Roman
	plt.rc('font',**{'family':'serif','serif':['Palatino']})
	plt.rc('text', usetex=True)
	plt.rc('font', family='serif')
	plt.xlabel(r'$E$ [GeV]')
	plt.ylabel(r'$E^3 \phi \left( \frac{\textrm{GeV}^2}{\textrm{cm}^2 \textrm{s sr}} \right)$')
	plt.title(r'\textrm{Prompt Neutrino Flux}')

	#default xy range
	plt.ylim([1e-6,1e-2])
	plt.xlim([1e3,pow(10,7.5)])

	#setting log scale
	ax1.set_yscale('log')
	ax1.set_xscale('log')

	#color and line style
	colors = ('b', 'g', 'r', 'c', 'y')
	dashedlines = [[100000,1],[4,4],[8,4,8,4],[8,2,2,2],[8, 4, 2, 4, 2, 4]]

	lines = []
	for i in range(0, nfluxes):	
		#loading data
		inputdir  = "outputs/"
		inputfile = fluxes[i] + "flux.dat"
		x,yc,yu,yl = np.loadtxt(inputdir + inputfile, skiprows=3, unpack=True)

		with open (inputdir + inputfile, "r") as f:
			
			first_line = f.readline()
			string=first_line.strip("CRF model")

			#adjust x range
			plt.xlim([x[0],x[-1]])

			#plotting
			p1, = ax1.plot(x,yc,c=colors[i], dashes=dashedlines[i])
			p2, = ax1.plot(x,yc,c=colors[i], dashes=dashedlines[i])
			if band:
				ax1.fill_between(x, yl, yu, facecolor=colors[i], alpha=0.2)
				p2, =ax1.plot([], [], color=colors[i], alpha=0.2, linewidth=10)

			lines += ((p1,p2),)
	#legend
	ax1.legend(lines, fluxes,loc='upper left')

	#write output
	outputdir = "plots/"
	plt.savefig(outputdir + output)

if __name__ == "__main__":
	main()
